From 0387bb770f484410d11ed72b483297fa5d06555d Mon Sep 17 00:00:00 2001
From: Von Welch <von@vwelch.com>
Date: Thu, 17 Apr 2014 21:34:32 -0400
Subject: [PATCH] Added -t/--tail support

---
 man/pass.1            |  3 ++-
 src/password-store.sh | 19 +++++++++++++++----
 2 files changed, 17 insertions(+), 5 deletions(-)

diff --git a/man/pass.1 b/man/pass.1
index 86946fb..ea51ef2 100644
--- a/man/pass.1
+++ b/man/pass.1
@@ -84,12 +84,13 @@ List names of passwords inside the tree that match \fIpass-names\fP by using the
 .BR tree (1)
 program. This command is alternatively named \fBsearch\fP.
 .TP
-\fBshow\fP [ \fI--clip\fP, \fI-c\fP ] \fIpass-name\fP
+\fBshow\fP [ \fI--clip\fP, \fI-c\fP ] [ \fI--tail\fP, \fI-t\fP ] \fIpass-name\fP
 Decrypt and print a password named \fIpass-name\fP. If \fI--clip\fP or \fI-c\fP
 is specified, do not print the password but instead copy the first line to the
 clipboard using
 .BR xclip (1)
 and then restore the clipboard after 45 (or \fIPASSWORD_STORE_CLIP_TIME\fP) seconds.
+If \fI--tail\fP or \fI-t\fP is specified, print the second and subsequent lines.
 .TP
 \fBinsert\fP [ \fI--echo\fP, \fI-e\fP | \fI--multiline\fP, \fI-m\fP ] [ \fI--force\fP, \fI-f\fP ] \fIpass-name\fP
 Insert a new password into the password store called \fIpass-name\fP. This will
diff --git a/src/password-store.sh b/src/password-store.sh
index ddedebd..1078e6f 100755
--- a/src/password-store.sh
+++ b/src/password-store.sh
@@ -207,7 +207,7 @@ cmd_usage() {
 	        List passwords.
 	    $PROGRAM find pass-names...
 	    	List passwords that match pass-names.
-	    $PROGRAM [show] [--clip,-c] pass-name
+	    $PROGRAM [show] [--clip,-c] [--tail,-t] pass-name
 	        Show existing password and optionally put it on the clipboard.
 	        If put on the clipboard, it will be cleared in $CLIP_TIME seconds.
 	    $PROGRAM grep search-string
@@ -281,13 +281,15 @@ cmd_init() {
 
 cmd_show() {
 	local clip=0
+	local tail=0
 
 	local opts
-	opts="$($GETOPT -o c -l clip -n "$PROGRAM" -- "$@")"
+	opts="$($GETOPT -o "ct" -l "clip,tail" -n "$PROGRAM" -- "$@")"
 	local err=$?
 	eval set -- "$opts"
 	while true; do case $1 in
 		-c|--clip) clip=1; shift ;;
+		-t|--tail) tail=1; shift ;;
 		--) shift; break ;;
 	esac done
 
@@ -300,11 +302,20 @@ cmd_show() {
 	local passfile="$PREFIX/$path.gpg"
 	if [[ -f $passfile ]]; then
 		if [[ $clip -eq 0 ]]; then
-			exec $GPG -d $GPG_OPTS "$passfile"
+			if [[ $tail -eq 0 ]]; then
+				exec gpg2 -d $GPG_OPTS "$passfile"
+			else
+				exec gpg2 -d $GPG_OPTS "$passfile" | tail -n +2
+			fi
 		else
 			local pass="$($GPG -d $GPG_OPTS "$passfile" | head -n 1)"
 			[[ -n $pass ]] || exit 1
-			clip "$pass" "$path"
+			gpg2 -d $GPG_OPTS "$passfile" | {
+				read -r pass
+				[[ -n $pass ]] || exit 1
+				clip "$pass" "$path"
+				[[ $tail -eq 1 ]] && cat ;
+			}
 		fi
 	elif [[ -d $PREFIX/$path ]]; then
 		if [[ -z $path ]]; then
-- 
1.8.5.2

